@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
 our $DATE = '2016-10-29'; # DATE
-our $VERSION = '1.43'; # VERSION
+our $VERSION = '1.44'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -24,6 +24,7 @@ our @EXPORT = (
     'pericmd_run_suite_ok',
     'pericmd_run_ok',
     'pericmd_run_test_groups_ok',
+    'pericmd_run_tests_ok',
 );
 
 our %SPEC;
@@ -495,6 +496,39 @@ sub pericmd_run_ok {
     pericmd_run_test_groups_ok(%rtg_args);
 }
 
+$SPEC{pericmd_run_tests_ok} = {
+    v => 1.1,
+    summary => 'Run a group of tests of a Perinci::CmdLine script',
+    args => {
+        %common_args,
+        tests => {
+            schema => ['array*', of=>'hash*'],
+            req => 1,
+        },
+    },
+};
+sub pericmd_run_tests_ok {
+    my %args = @_;
+
+    my %rtg_args;
+
+    $rtg_args{class} = delete $args{class};
+
+    {
+        my $group = {
+            name => 'single group (pericmd_run_tests_ok)',
+        };
+        if (grep {$_->{comp_answer}} @{ $args{tests} }) {
+            $group->{completion_tests} = delete $args{tests};
+        } else {
+            $group->{tests} = delete $args{tests};
+        }
+        $rtg_args{groups} = [$group];
+    }
+
+    pericmd_run_test_groups_ok(%rtg_args);
+}
+
 $SPEC{pericmd_run_suite_ok} = {
     v => 1.1,
     summary => 'Common test suite for Perinci::CmdLine::{Lite,Classic,Inline}',
@@ -1713,7 +1747,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.43 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-10-29.
+This document describes version 1.44 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-10-29.
 
 =for Pod::Coverage ^(pericmd_ok)$
 
@@ -1916,6 +1950,36 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 pericmd_run_tests_ok(%args) -> [status, msg, result, meta]
+
+Run a group of tests of a Perinci::CmdLine script.
+
+This function is exported by default.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<class>* => I<str>
+
+Which Perinci::CmdLine class are we testing.
+
+=item * B<tests>* => I<array[hash]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 ENVIRONMENT
 
 =head2 DEBUG => bool
